@@ -16,7 +16,7 @@ from kupala.middleware import Middleware
 from kupala.requests import Request
 from kupala.resources import get_resource_action
 from kupala.responses import RedirectResponse
-from kupala.utils import camel_to_snake
+from kupala.utils import camel_to_snake, import_string
 
 
 def apply_middleware(app: t.Callable, middleware: t.Sequence[Middleware]) -> ASGIApp:
@@ -633,6 +633,19 @@ class Routes(t.Sequence[routing.BaseRoute]):
             id_param=id_param,
         )
 
+    def include(
+        self, iterable_or_module: t.Union[t.Iterable[routing.BaseRoute], str], callback: str = 'configure'
+    ) -> None:
+        """Include routes."""
+        IncludeRoutesCallback = t.Callable[[Routes], None]
+        if isinstance(iterable_or_module, str):
+            if ':' not in iterable_or_module:
+                iterable_or_module += ':' + callback
+            configure_callback: IncludeRoutesCallback = import_string(iterable_or_module)
+            configure_callback(self)
+        else:
+            self._routes.extend(list(iterable_or_module))
+
     def __iter__(self) -> t.Iterator[routing.BaseRoute]:
         return iter(self._routes)
 
